==> vokoscreen-ng_3.0.5.orig.tar.gz: vokoscreenNG-3.0.5/src/language/nl_NL.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl_NL" version="2.1">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Selecteer één of meer apparaten</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Wissel naar vensterweergave</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Wissel naar volledig scherm</translation>
    </message>
</context>
<context>
    <name>QvkCountdown</name>
    <message>
        <source>Countdown</source>
        <translation>Countdown</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Selecteer één of meer apparaten</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Help</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Waarschuwing</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>De opname is niet begonnen omdat er niet genoeg schijfruimte beschikbaar is.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>De  vrijeschijfruimtelimiet is bereikt.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Vrijeschijfruimtelimiet</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>De opname is gestopt omdat er niet genoeg schijfruimte beschikbaar is.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Volledig scherm</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Venster</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Er is geen bestandsbeheerder gevonden.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Installeer een bestandsbeheerder.</translation>
    </message>
    <message>
        <source>Desktop session is a Wayland session</source>
        <translation>De bureaubladsessie is een Wayland-sessie</translation>
    </message>
    <message>
        <source>To time Wayland is not supported. A screencast show a black screen. Please logout and start a X11 Desktop session</source>
        <translation>Op dit moment is Wayland niet ondersteund. Screencasts zullen een zwart scherm tonen. Log uit en start een X11-bureaubladsessie.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Broncode</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Startpagina</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Vertalingen</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Doneren</translation>
    </message>
    <message>
        <source>Wayland desktop session detected</source>
        <translation>Wayland bureaubladsessie gedetecteerd.</translation>
    </message>
</context>
<context>
    <name>QvkPlayer</name>
    <message>
        <source>Open File</source>
        <translation>Open bestand</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Gebied</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Starten</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stoppen</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauzeren</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Doorgaan</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Einde</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Starten</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stoppen</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauzeren</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Doorgaan</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Einde</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialoog</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Flip horizontaal</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Flip verticaal</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Omkeren</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grijs</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Zwart-wit</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Verwijder schermkader</translation>
    </message>
    <message>
        <source>160x120</source>
        <translation>160x120</translation>
    </message>
    <message>
        <source>320x240</source>
        <translation>320x240</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Camera-instellingen</translation>
    </message>
    <message>
        <source>640x480</source>
        <translation>640x480</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Gebied</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Reset</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Vergroting</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Countdown</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Videoformaat:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Vrije schijfruimte:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informatie</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Opnametijd:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Frames</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Videocodec</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formaat</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Audiocodec</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Kwaliteit</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Muiscursor niet opnemen</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Uur</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minuut</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Start de timer</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Stop opname na</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Uren</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minuten</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Seconden</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Video map</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Vrijeschijfruimtelimiet</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Tonen in systray</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Secondes wachten voor opname</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Zoek naar updates</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Beschikbaar</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Niet beschikbaar</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Starten</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stoppen</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauzeren</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Doorgaan</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Afspelen</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Map</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Omkeren</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grijs</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Stuur rapportage</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Speel laatste opname af</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Open map</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Geminimaliseerd wanneer de opname start</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Start geminimaliseerd</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Flip horizontaal</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Flip verticaal</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Zwart-wit</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Verwijder schermkader</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Doneren</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Alle instellingen herstellen bij opnieuw opstarten</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Copyright en licentie uit beelden</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Screencast</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Speler</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Log</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Copyright en licentie uit beelden</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Afspelen</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauzeren</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stoppen</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Open bestand</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Volledig scherm</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Vorige frame</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Volgende frame</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Demp</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Verplaats menu</translation>
    </message>
</context>
</TS>

==> vokoscreen-ng_3.0.7.orig.tar.gz: vokoscreenNG-3.0.7/src/language/nl_NL.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl_NL" version="2.1">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Selecteer één of meer apparaten</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Vensterweergave</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Beeldvullende weergave</translation>
    </message>
</context>
<context>
    <name>QvkCountdown</name>
    <message>
        <source>Countdown</source>
        <translation>Aftellen</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Selecteer één of meer apparaten</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Hulp</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Waarschuwing</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>De opname is niet begonnen omdat er onvoldoende vrije schijfruimte is.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Het vrijeschijfruimtelimiet is bereikt.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Vrijeschijfruimtelimiet</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>De opname is gestopt omdat er onvoldoende vrije schijfruimte is.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Beeldvullend</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Venster</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Er is geen bestandsbeheerder gevonden.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Installeer een bestandsbeheerder.</translation>
    </message>
    <message>
        <source>Desktop session is a Wayland session</source>
        <translation>De bureaubladsessie is een Wayland-sessie</translation>
    </message>
    <message>
        <source>To time Wayland is not supported. A screencast show a black screen. Please logout and start a X11 Desktop session</source>
        <translation>Wayland wordt momenteel niet ondersteund - screencasts zullen een zwart scherm tonen. Log uit en start een X11-bureaubladsessie.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Broncode</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Website</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Vertalingen</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Doneren</translation>
    </message>
    <message>
        <source>Wayland desktop session detected</source>
        <translation>Wayland-bureaubladsessie gedetecteerd</translation>
    </message>
</context>
<context>
    <name>QvkPlayer</name>
    <message>
        <source>Open File</source>
        <translation>Bestand openen</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Gebied</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Starten</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stoppen</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Onderbreken</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Hervatten</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Afsluiten</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Starten</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stoppen</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Onderbreken</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Hervatten</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Afsluiten</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialoogvenster</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Horizontaal spiegelen</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Verticaal spiegelen</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Omkeren</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grijs</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Zwart-wit</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Vensterrand verwijderen</translation>
    </message>
    <message>
        <source>160x120</source>
        <translation>160x120</translation>
    </message>
    <message>
        <source>320x240</source>
        <translation>320x240</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Camera-instellingen</translation>
    </message>
    <message>
        <source>640x480</source>
        <translation>640x480</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Gebied</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Standaardwaarden</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Vergroting</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Aftellen</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Videoformaat:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Vrije schijfruimte:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informatie</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Opnametijd:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Frames</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Videocodec</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formaat</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Audiocodec</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Kwaliteit</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Cursor niet vastleggen</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Uur</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minuut</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Tijdklok starten</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Opname stoppen na</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Uur</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minuten</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Seconden</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Videomap</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Vrijeschijfruimtelimiet</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Tonen in systeemvak</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Aantal seconden voordat opname start</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Controleren op updates</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hulp</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Beschikbaar</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Niet beschikbaar</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Starten</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stoppen</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Onderbreken</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Hervatten</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Afspelen</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Map</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Omkeren</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Grijs</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>Rapportage versturen</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Recentste opname afspelen</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Map openen</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Minimaliseren als opname start</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Geminimaliseerd starten</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Horizontaal spiegelen</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Verticaal spiegelen</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Zwart-wit</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Vensterrand verwijderen</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Doneren</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Alle instellingen herstellen bij opnieuw opstarten</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Copyright en licentie uit beelden</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Screencast</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Speler</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Logboek</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Copyright en licentie uit beelden</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Afspelen</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauzeren</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stoppen</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Bestand openen</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Beeldvullend</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Vorig frame</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Volgend frame</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Dempen</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Menu verplaatsen</translation>
    </message>
</context>
</TS>
